<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Ürít</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Megfejt</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Megfejtett</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Átlagos</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Kihagyott</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hibás</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sikeres</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Vége a játéknak</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 / %n pont</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 / %n pont</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 / %n pont</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 / %n pont</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 / %n pont</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n pont</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>A legmagasabb elérhető pontszám a következő harminc szóból került kiszámításra:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n megfejtés</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n hiba</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klasszikus</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Újratöltő</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Kitartó</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Büntető</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Tarsoly</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Fegyelem</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Visszaszámlálás 30 másodpercről és megfejtés esetén időt nyersz.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Visszaszámlálás 3 percről.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Visszaszámlálás 30 másodpercről és ez minden megfejtésnél újraindul.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Visszaszámlálás 45 másodpercről és megfejtés esetén szünidőt nyersz.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>3 hibás megfejtés után vége a játéknak.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>30 megfejtés után vége a játéknak.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Visszaszámlálás 30 másodpercről és helyes vagy hibás megfejtés esetén időt nyersz vagy vesztesz.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Nem sikerült beolvasni a kocka fájlt.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Nem sikerült beolvasni a szó-lista fájlt.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Szavak nyelve</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Egyéni</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Kiválaszt...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Megjegyzés:&lt;/b&gt; A változások új játék esetén lépnek érvénybe.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Nyelv:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Kocka:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Szavak listája:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Szótár:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Kocka fájl kiválasztása</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Szó-lista fájl kiválasztása</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Program nyelve:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Rendszer nyelve&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>A nyelvi változások érvénybelépéséhez újra kell indítani a programot.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Új játék</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Szavak száma:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Legrövidebb szó:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Kevés</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Sok</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Véletlenszerű</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n betű</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Eredmények</translation>
    </message>
    <message>
        <source>&lt;b&gt;Name&lt;/b&gt;</source>
        <translation>&lt;b&gt;Név&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Score&lt;/b&gt;</source>
        <translation>&lt;b&gt;Eredmény&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Date&lt;/b&gt;</source>
        <translation>&lt;b&gt;Dátum&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
        <translation>&lt;b&gt;Típus&lt;/b&gt;</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Clear high scores?</source>
        <translation>Eredmények törlése?</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Szünet&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Kattints a folytatáshoz.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Kérlek várj&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Játék betöltése...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Kattints az új játékhoz.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Kérlek várj&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Új tábla készítése...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Kérlek várj&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Szó-lista optimalizációja...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Játék</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Új &amp;játék...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>Új&amp;rakever</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>K&amp;iválaszt...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Megoszt...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Befejez</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Szünet</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>Részle&amp;tek</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Eredmények</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>B&amp;eállítások</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Elérhető &amp;pontok</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Ne mutasd</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>Játék &amp;végén</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Mindig</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>El&amp;hibázott szavak</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Szavak szá&amp;ma</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Szavak &amp;nyelve...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Program nye&amp;lve...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Irányítás</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>About &amp;Hspell</source>
        <translation>&amp;Hspell névjegye</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt névjegye</translation>
    </message>
    <message>
        <source>About &amp;SCOWL</source>
        <translation>&amp;SCOWL névjegye</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>A &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; egyjátékos változata</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Angol szó-lista fájl Kevin Atkinson &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; listája alapján</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Héber szó-lista fájl Nadav Har&apos;El és Dan Kenigsberg &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; listája alapján</translation>
    </message>
    <message>
        <source>About Hspell</source>
        <translation>Hspell névjegye</translation>
    </message>
    <message>
        <source>About SCOWL</source>
        <translation>SCOWL névjegye</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Játék betöltése</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Tanglet játékok (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nem sikerült elindítani a kívánt játékot.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Játék mentése</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Játék befejezése?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Tábla mérete:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Átlagos</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Szavak száma:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Szavak hossza:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 vagy több betű</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Játék típusa:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Leírás:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Irányítás</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Egérrel:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Szó kiválasztása:&lt;/b&gt; Kattints a szó betűire.&lt;br&gt;&lt;b&gt;Megfejtés:&lt;/b&gt; Kattints az utolsó kijejölt betűre.&lt;br&gt;&lt;b&gt;Betű törlése:&lt;/b&gt; Kattints a korábban kijelölt betűre.&lt;br&gt;&lt;b&gt;Szó törlése:&lt;/b&gt; Kattints kétszer az első kijelölt betűre.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Billentyűzettel:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Szó kiválasztása:&lt;/b&gt; Írd be a szó betűit.&lt;br&gt;&lt;b&gt;Megfejtés:&lt;/b&gt; Üsd le az Enter billentyűt.&lt;br&gt;&lt;b&gt;Szó törlése:&lt;/b&gt; Üsd le a Ctrl+Backspace billentyűkombinációt.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Betűk:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Megfejtett:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n pont</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
